@@ -2,7 +2,8 @@
 #' @description Use Survival() function from 'rms' pacakge to calculate probabilities after lrm(), cph() or psm() regression. If you want to calculate lrm() probabilities, please leave linear.predictors be TRUE and times be missing. If you want to calculate cph() probabilites, please leave both linear.predictors and surv be TRUE.
 #' @param reg regression results after lrm(), cph() or psm() in 'rms' package.
 #' @param times if you want to calculate probabilities for lrm() function, please left times missing.
-#'
+#' @param q quantile, for example 0.5
+#' @param lp linear predictors
 #' @return lieaner predictors and probabilities as a dataframe
 #' @export
 #'
@@ -19,6 +20,9 @@
 #' df <- data.frame(time,death,age,sex,weight)
 #' 
 #' library(rms) #needed for lrm(), cph() and psm()
+#' ddist <- datadist(df)
+#' oldoption <- options(datadist='ddist')
+#' 
 #' # lrm() function
 #' f <- lrm(death~sex+age+weight,data=df,
 #'          linear.predictors = TRUE)
@@ -32,16 +36,22 @@
 #' # psm() function
 #' f <- psm(Surv(time,death)~sex+age+weight,data=df)
 #' head(prob_cal(reg = f,times = c(365,365*2)))
-prob_cal <- function(reg,times){
+prob_cal <- function(reg,times,q,lp){
     if (!'linear.predictors' %in% names(reg)){
         stop('linear preditors must be included in reg') 
     }
-    linear.predictors=reg$linear.predictors
-    if (missing(times)){
+    if (missing(lp)){
+        linear.predictors=reg$linear.predictors
+    }else{
+        linear.predictors=lp
+    }
+    if (all(missing(times),missing(q))){
+        #for logistic ratio
         result=1/(1+exp(-linear.predictors))
         result=data.frame(result)
         colnames(result)='Prob'
-    }else{
+    }else if (all(!missing(times),missing(q))){
+        #for survival regression times
         surv <- rms::Survival(reg)
         for (i in 1:length(times)) {
             if (i==1){
@@ -55,7 +65,22 @@ prob_cal <- function(reg,times){
                 result=cbind(result,result.i)
             }
         }
+    }else if (all(missing(times),!missing(q))){
+        #for survival regression quantile
+        qtl <- Hmisc::Quantile(reg)
+        for (i in 1:length(q)) {
+            if (i==1){
+                result=qtl(q[i],linear.predictors)
+                result=data.frame(result)
+                colnames(result)=paste0('P',q[i])
+            }else{
+                result.i=qtl(q[i],linear.predictors)
+                result.i=data.frame(result.i)
+                colnames(result.i)=paste0('P',q[i])
+                result=cbind(result,result.i)
+            }
+        }
     }
     result=cbind(linear.predictors,result)
     return(result)
-}
\ No newline at end of file
+}
